@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Lovely Systems and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -13,18 +13,14 @@
 ##############################################################################
 """Test the Dublin Core Property implementation
 
-$Id: test_property.py 104029 2009-09-15 10:29:47Z nadako $
+$Id: test_property.py 111143 2010-04-19 20:05:31Z tseaver $
 """
 __docformat__ = "reStructuredText"
 
 import doctest
 import unittest
-
 from zope import component
-
-from zope.testing.doctestunit import DocFileSuite
 from zope.testing import cleanup
-
 from zope.annotation.attribute import AttributeAnnotations
 from zope.dublincore import testing
 
@@ -34,15 +30,18 @@ def setUp(test):
     component.provideAdapter(AttributeAnnotations)
     testing.setUpDublinCore()
 
+
 def tearDown(test):
     cleanup.tearDown()
 
+
 def test_suite():
     return unittest.TestSuite(
         (
-        DocFileSuite('../property.txt',
-                     setUp=setUp,
-                     tearDown=tearDown,
-                     optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
-                     ),
+        doctest.DocFileSuite(
+            '../property.txt',
+             setUp=setUp,
+             tearDown=tearDown,
+           optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS,
+           ),
         ))
